@@ -100,3 +100,7 @@ class benedict(IODict, KeypathDict, ParseDict, UtilityDict):
     @benediction
     def setdefault(self, key, default=None):
         return super(benedict, self).setdefault(key, default)
+
+    @benediction
+    def subset(self, keys):
+        return super(benedict, self).subset(keys)
